/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 XQuark Group.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

package org.xquark.repository.dbms.mysql;

import java.sql.*;
import java.util.HashMap;
import java.util.Map;

import org.xquark.repository.dbms.DBMSInfo;
import org.xquark.repository.dbms.JDBC2Connection;
import org.xquark.repository.mapping.ColumnMetaData;
import org.xquark.repository.mapping.mysql.MySQLColumnMetaData;

/**
 * Implementation of AbstractConnection for MySQL databases.
 * 
 * NOTE: Bridge only. Not adapted to Repository requirements.
 */
public class MySQL323Connection extends JDBC2Connection
{
    private static final String RCSRevision = "$Revision: 1.3 $"; 
    private static final String RCSName     = "$Name:  $";
    
   /** Creates new O8iConnection */
    public MySQL323Connection(Connection connection, short dbms, DBMSInfo dbmsInfo)
    throws SQLException
    {
        super(connection, dbms, dbmsInfo);
    }
    
	/** Retrieves org.xquark.repository.mapping.ColumnMetadata from the
	 * underlying database.
	 * @param tableName The table name
	 * @throws SQLException If a database error occurs while creation
	 */
	public Map getTableMetadata(String tableName) throws SQLException {
		HashMap columns = new HashMap();
		DatabaseMetaData metadata = connection.getMetaData();
		ResultSet rs = metadata.getColumns(connection.getCatalog(), schemaName, getMetadataConvertedName(tableName), null); // SR 18/12/2000 Oracle is case-sensitive for metadata ! TO IMPROVE.
		try {
			while (rs.next()) {
				ColumnMetaData cmeta = new MySQLColumnMetaData(rs, getTypeMap());
				columns.put(cmeta.getColumnName(), cmeta);
			}
		} finally {
			rs.close();
		}
		return columns;
	}

}
